@@ -454,7 +454,7 @@ See also variables `lazy-lock-walk-windows' and `lazy-lock-ignore-commands'."
     ;; Do the visible parts of the buffer(s), i.e., the window(s).
     (if (or (not lazy-lock-walk-windows)
 	    (and (eq lazy-lock-walk-windows t) (one-window-p t)))
-	(or (window-minibuffer-p)
+       (or (window-minibuffer-p (selected-window))
 	    (lazy-lock-maybe-fontify-window (selected-window)))
       (walk-windows #'lazy-lock-maybe-fontify-window
 		    'no-minibuf (eq lazy-lock-walk-windows 'all-frames)))))
@@ -472,7 +472,7 @@ See also variables `lazy-lock-walk-windows' and `lazy-lock-ignore-commands'."
   ;; from FSF Emacs, which doesn't (or didn't?) have built-in timers.
   ;; using sit-for is unfriendly and can cause weird interactions.
   (when (and (not (memq this-command lazy-lock-ignore-commands))
-	     (not (window-minibuffer-p))
+            (not (window-minibuffer-p (selected-window)))
 	     lazy-lock-stealth-time)
     (if lazy-lock-timeout-id (disable-timeout lazy-lock-timeout-id))
     (setq lazy-lock-timeout-id
