@@ -188,13 +188,15 @@ potentially taking a long time."
 (defun manual-entry (topic &optional arg silent)
   "Display the Unix manual entry (or entries) for TOPIC."
   (interactive
-   (list (let* ((fmh "-A-Za-z0-9_.:")
+   (list (let* ((fmh "-A-Za-z0-9_.:()")
 		(default (save-excursion
 			   (buffer-substring
 			    (progn
 			      (re-search-backward "\\sw" nil t)
 			      (skip-chars-backward fmh) (point))
-			    (progn (skip-chars-forward fmh) (point)))))
+			    (progn
+                              (skip-chars-forward fmh)
+                              (skip-chars-backward ".") (point)))))
 		(thing (read-string
 			(if (equal default "") "Manual entry: "
 			  (concat "Manual entry: (default " default ") "))
@@ -203,6 +205,10 @@ potentially taking a long time."
 	 (prefix-numeric-value current-prefix-arg)))
   (let (buffer)
     (or arg (setq arg 1))
+    ;; Allow leading chapter numbers
+    (if (string-match "\\([1-9n][a-zA-Z0-9]*\\) \\(.*\\)" topic)
+	(setq topic (replace-match "\\2(\\1)" t nil topic))
+      )
     (let (section apropos-mode)
       (let ((case-fold-search nil))
 	(if (and (null section)
